@@ -6,7 +6,7 @@ class Utils:
     def get_nim_headers(cls, request):
         NIM_HEADER_REG_EXP = r"^HTTP\_NIM\_"
         HTTP_REG_EXP = r"^HTTP\_"
-        nim_headers = {}
+        nim_headers = dict()
         for key, value in request.META.items():
             if re.match(NIM_HEADER_REG_EXP, key):
                 transformed_key = re.sub(HTTP_REG_EXP, "", key).replace("_", "-")
@@ -14,6 +14,18 @@ class Utils:
 
         return nim_headers
 
+    @classmethod
+    def get_all_headers(cls, request):
+        headers = dict()
+        for key, value in request.META.items():
+            headers[key] = value
+
+        return headers
+
+    @classmethod
+    def get_header_by_name(cls, request, header_name, default_value):
+        return request.META.get(header_name, default_value)
+
     @classmethod
     def adjust_string_length(cls, value, max_length):
         TRUNCATE_INDICATOR = "---[TRUNCATED]---"
